@@ -319,6 +319,11 @@ gboolean callback_tag_event(GtkTextTag *tag, GObject *object, GdkEvent *event, G
 /* Callback for hardware D-BUS events */
 void hw_event_handler(osso_hw_state_t *state, MainView *mainview) {
  	g_assert(mainview != NULL && mainview->data != NULL );
+ 	
+ 	if ((state->system_inactivity_ind) && isRecBeingEdited(mainview)) {
+		// Bug 9250
+		return;
+	}
 
 	if ((state->shutdown_ind)	/* system shutdown */
 			|| (state->system_inactivity_ind)) {	/* system sleeping */
