@@ -503,10 +503,12 @@ void read_pwsafe_file(MainView* mainview) {
 									recs=NULL;
 									buffer=readcbc(mainview, handle, &blowCTX, iv, &buffer_len, &rec_type);
 									if (v2) {
-										mainview->preferences=buffer;
+										mainview->preferences=g_strndup(buffer, buffer_len);
+										g_free(buffer);
 									} else {
 										if (buffer != NULL) {
-											entry->notes=buffer;
+											entry->notes=g_strndup(buffer, buffer_len);
+											g_free(buffer);
 											entry->group=g_strdup(_("Group"));
 											recs=g_list_insert_sorted(recs, entry, (GCompareFunc) rec_comparer);
 										}
@@ -531,23 +533,29 @@ void read_pwsafe_file(MainView* mainview) {
 															g_free(buffer);
 															new_uuid(entry);
 														} else {
-															entry->uuid=buffer;
+															entry->uuid=g_strndup(buffer, buffer_len);
+															g_free(buffer);
 														}
 														break;
 													case GROUP:
-														entry->group=buffer;
+														entry->group=g_strndup(buffer, buffer_len);
+														g_free(buffer);
 														break;
 													case TITLE:
-														entry->title=buffer;
+														entry->title=g_strndup(buffer, buffer_len);
+														g_free(buffer);
 														break;
 													case USER:
-														entry->user=buffer;
+														entry->user=g_strndup(buffer, buffer_len);
+														g_free(buffer);
 														break;
 													case NOTES:
-														entry->notes=buffer;
+														entry->notes=g_strndup(buffer, buffer_len);
+														g_free(buffer);
 														break;
 													case PASSWORD:
-														entry->password=buffer;
+														entry->password=g_strndup(buffer, buffer_len);
+														g_free(buffer);
 														break;
 													case END:
 														if (!entry->uuid) {
@@ -559,9 +567,9 @@ void read_pwsafe_file(MainView* mainview) {
 														entry->uuid=entry->group=entry->title=entry->user=entry->notes=entry->password=NULL;
 														break;
 													default: /* unknown block... just delete it and move on. */
-														if (buffer_len>0) {
+														//if (buffer_len>0) {
 															g_free(buffer);
-														}
+														//}
 												}
 											} else {
 												if (buffer != NULL) {
@@ -569,10 +577,12 @@ void read_pwsafe_file(MainView* mainview) {
 													getV1UserTitle(buffer, entry);
 													buffer=readcbc(mainview, handle, &blowCTX, iv, &buffer_len, &rec_type);
 													if (buffer != NULL) {
-														entry->password=buffer;
+														entry->password=g_strndup(buffer, buffer_len);
+														g_free(buffer);
 														buffer=readcbc(mainview, handle, &blowCTX, iv, &buffer_len, &rec_type);
 														if (buffer != NULL) {
-															entry->notes=buffer;
+															entry->notes=g_strndup(buffer, buffer_len);
+															g_free(buffer);
 															entry->group=g_strdup(_("Group"));
 															recs=g_list_insert_sorted(recs, entry, (GCompareFunc) rec_comparer);
 															entry=g_malloc0(sizeof(rec));
